.. AUTO-GENERATED FILE -- DO NOT EDIT!

models.generic_selector
=======================

Module: :mod:`models.generic_selector`
--------------------------------------
Inheritance diagram for ``ISLP.models.generic_selector``:

.. inheritance-diagram:: ISLP.models.generic_selector 
   :parts: 3

.. automodule:: ISLP.models.generic_selector

.. currentmodule:: ISLP.models.generic_selector

:class:`FeatureSelector`
------------------------


.. autoclass:: FeatureSelector
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__
